summaryrefslogtreecommitdiffstats
path: root/source/slang/slang-emit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/slang/slang-emit.cpp')
-rw-r--r--source/slang/slang-emit.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/source/slang/slang-emit.cpp b/source/slang/slang-emit.cpp
index f1ec402dd..b34483cf2 100644
--- a/source/slang/slang-emit.cpp
+++ b/source/slang/slang-emit.cpp
@@ -783,12 +783,13 @@ Result linkAndOptimizeIR(
break;
}
// Legalize `ImageSubscript` for GLSL.
switch (target)
{
case CodeGenTarget::GLSL:
{
legalizeImageSubscriptForGLSL(irModule);
+ legalizeConstantBufferLoadForGLSL(irModule);
}
break;
default:
@@ -783,12 +783,13 @@ Result linkAndOptimizeIR(
break;
}
- // Legalize `ImageSubscript` for GLSL.
+ // Legalize `ImageSubscript` and constant buffer loads for GLSL.
switch (target)
{